"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.detectFileInclusion = detectFileInclusion;
const FILE_INCLUSION_PATTERNS = [
    /\.\.\/\.\.\//, // Directory traversal
    /\/etc\/passwd/, // Access to /etc/passwd file
    /\/proc\/self\/environ/, // Access to /proc/self/environ file
    /\binclude\b.*\bhttp:\/\//i, // Remote file inclusion using HTTP
    /\binclude\b.*\bftp:\/\//i, // Remote file inclusion using FTP
    /\.\.\\/, // Windows directory traversal
    /[a-zA-Z]:\\/, // Windows absolute path
    /\/\w+\/\.\.\//, // Directory traversal with named directories
    /\.\.\//, // Relative directory traversal
    /etc\/shadow/, // Access to /etc/shadow file
    /root\/\.ssh/, // Access to root's .ssh directory
    /windows\/system32/, // Access to Windows system32 directory
    /boot.ini/, // Access to boot.ini file
    /\bfile\b:\/\/\/?/, // Local file inclusion using file:// protocol
    /\bphp:\/\/input\b/, // PHP input stream
    /\bdata\b:text\/plain;base64,/, // Base64 encoded data
    /expect:\/\//, // Expect protocol
    /phar:\/\//, // Phar protocol
    /\bini_set\b/i, // ini_set function
    /\bopen_basedir\b/i, // open_basedir function
    /\bload_file\b/i, // load_file function
    /\binto\b\s+\boutfile\b/i, // INTO OUTFILE syntax
    /(?:(?:[a-zA-Z]:|\/)[\w.\/\\-]+)+\.\w{2,4}/, // File paths with extensions
    /\/etc\/passwd/, // Access to /etc/passwd file
    /\/etc\/shadow/, // Access to /etc/shadow file
    /\/proc\/self\/environ/, // Access to /proc/self/environ file
    /\bfile:\/\/\b/, // File protocol
    /\bphp:\/\/\b/, // PHP protocol
    /<\?php/i, // PHP opening tag
    /data:.*?base64,/, // Base64 encoded data
    /expect:\/\//i, // Expect protocol
    /phar:\/\//i, // Phar protocol
    /\bfile_put_contents\b/i, // file_put_contents function
    /\bexec\b/i, // exec function
    /\bsystem\b/i, // system function
    /\bshell_exec\b/i, // shell_exec function
    /\bpopen\b/i, // popen function
    /\bproc_open\b/i, // proc_open function
];
/**
 * Detects if there is a potential file inclusion vulnerability in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential file inclusion vulnerability is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common file inclusion patterns in the input string.
 * Patterns include directory traversal, remote file inclusion, and access to sensitive files and directories.
 *
 * @example
 * ```typescript
 * const input = "../../etc/passwd";
 * const isFileInclusion = detectFileInclusion(input);
 * console.log(isFileInclusion); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
function detectFileInclusion(input) {
    return FILE_INCLUSION_PATTERNS.some((pattern) => pattern.test(input));
}
//# sourceMappingURL=fileInclusionDetector.js.map