import { ScanRequestParams } from './interfaces/ITScanRequestParams';
/**
 * Escanea una solicitud HTTP en busca de posibles problemas de seguridad.
 *
 * @param params - Los parámetros de la solicitud a escanear.
 * @returns Un array de cadenas que representan los problemas de seguridad encontrados.
 *
 * @remarks
 * Esta función escanea una solicitud HTTP en busca de posibles problemas de seguridad en la URL, el cuerpo, los encabezados, los datos del formulario y las cookies.
 *
 * @param url - La URL de la solicitud.
 * @param body - El cuerpo de la solicitud.
 * @param headers - Los encabezados de la solicitud.
 * @param formData - Los datos del formulario de la solicitud.
 * @param cookies - Las cookies de la solicitud.
 * @param options - Las opciones de escaneo personalizadas.
 *
 * @returns Un array de cadenas que representan los problemas de seguridad encontrados.
 *
 * @example
 * const params: ScanRequestParams = {
 *   url: 'https://example.com',
 *   body: { username: 'admin', password: 'password' },
 *   headers: { 'Content-Type': 'application/json' },
 *   formData: new FormData(),
 *   cookies: { sessionId: '1234567890' },
 *   options: {
 *     checkUrl: { enabled: true, values: ['admin', 'password'] },
 *     checkBody: { enabled: true, values: ['admin', 'password'] },
 *     checkHeaders: { enabled: true, values: ['admin', 'password'] },
 *     checkFormData: { enabled: true, values: ['admin', 'password'] },
 *     checkCookies: { enabled: true, values: ['admin', 'password'] },
 *   },
 * };
 *
 * const issues = scanRequest(params);
 * console.log(issues);
 *  Output: ['The URL contains sensitive information: admin', 'The body contains sensitive information: password']
 *
 * @author Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export declare function scanRequest(params: ScanRequestParams): string[];
